@@ -2,11 +2,15 @@
 kml_compress <- function(file.name, zip = Sys.getenv("R_ZIPCMD", "zip"), files = "", rm = FALSE, ...){
 
   # Changing the extension to KMZ
-  extension <- file_ext(file.name)
-  kmz <- str_replace(file.name, extension, "kmz") # switch the extension to kmz
+  extension <- tools::file_ext(file.name)
+  kmz <- stringr::str_replace(file.name, extension, "kmz") # switch the extension to kmz
 	
   # use R's zip wrapper
-  try(x <- zip(zipfile=paste(getwd(), kmz, sep='/'), files=paste(getwd(), file.name, sep='/'), zip=zip))
+  if(.Platform$OS.type == "windows") {
+    try( x <- zip(zipfile = utils::shortPathName(kmz), files= utils::shortPathName(file.name), zip = zip) )
+  } else {
+    try( x <- zip(zipfile = kmz, files= file.name, zip = zip) )
+  }
   # Error handling
   if(is(.Last.value, "try-error")| x==127) {
     if(zip==""|!nzchar(zip)){
@@ -19,7 +23,7 @@ kml_compress <- function(file.name, zip = Sys.getenv("R_ZIPCMD", "zip"), files =
   # clean-up
   if (file.exists(kmz) & rm==TRUE) {
   	x <- file.remove(file.name, files)
-  	}
+  }
 
 }
 
